@@ -1,5 +1,5 @@
 from django.contrib import admin
-from django.urls import include, path, reverse_lazy
+from django.urls import path, reverse_lazy
 from django.views.generic import RedirectView
 
 admin.autodiscover()
